/*
 * @(#)BuildCustomer
 *
 * Copyright (c) 1998 Karl Moss. All Rights Reserved.
 *
 * You may study, use, modify, and distribute this software for any
 * purpose provided that this copyright notice appears in all copies.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @version 1.0
 * @date    11Mar98
 *
 */

package javaservlets.rmi.server;
 
import java.sql.*;
import javaservlets.db.*;

/**
 * <p>This applications builds the sample customer database.
 */

public class BuildCustomer
{
  String m_tableName = "Customer";
  
  /**
    * <p>Main entry point for the application
    *
    * The usage for the application is:
    *
    *   BuildCustomer <driver> <URL> [<user>] [<password>]
    *
    * where
    *   driver   = the JDBC driver class name to use (such as
    *              sun.jdbc.odbc.JdbcOdbcDriver)
    *   URL      = the JDBC connection URL
    *   user     = the optional user name
    *   password = the optional password
    */
  public static void main(String args[])
    {
      String driver = null;
      String url = null;
      String user = null;
      String password = null;
      boolean needHelp = false;

      // Get the driver name
      if (args.length > 0) {
        driver = args[0];
      }
      else {
        needHelp = true;
      }

      // Get the URL
      if (args.length > 1) {
        url = args[1];
      }
      else {
        needHelp = true;
      }

      // Get the optional user name
      if (args.length > 2) {
        user = args[2];
      }

      // Get the optional password
      if (args.length > 3) {
        password = args[3];
      }

      // If the user needs help with the arguments, display it
      if (needHelp) {
        System.out.println("\nUsage: BuildCustomer <driver> " +
                           "<URL> [<user>] [<password>]");
      }
      else {
        BuildCustomer o = new BuildCustomer();
        o.build(driver, url, user, password);
      }
    }

  /**
    * <p>Build the database table
    *
    * @param driver JDBC driver class name
    * @param url JDBC connection URL
    * @param user User name
    * @param password User password
    */
  private void build(String driver, String url,
                     String user, String password)
    {
      java.sql.Connection con = null;
      java.sql.PreparedStatement ps = null;
      
      try {
        
        // Attempt to create a new instance of the specified
        // JDBC driver. Well behaved drivers will register
        // themselves with the JDBC DriverManager when they
        // are instantiated
        trace("Registering " + driver);
        java.sql.Driver d = (java.sql.Driver)
          Class.forName(driver).newInstance();

        // Create a connection to the given URL
        con = java.sql.DriverManager.getConnection(url, user,
                                                   password);

        // Create a new helper class
        SQLHelper helper =
          new javaservlets.db.SQLHelper(con);

        // Drop the table
        trace("Dropping existing " + m_tableName + " table");
        helper.drop(m_tableName);

        // Setup the columns
        ColumnDesc cols[] = new ColumnDesc[3];
        cols[0] = new ColumnDesc("Custno", Types.INTEGER);
        cols[1] = new ColumnDesc("Name", Types.VARCHAR);
        cols[2] = new ColumnDesc("Balance", Types.NUMERIC, 10, 2);

        // Create the table
        trace("Creating table " + m_tableName);
        helper.create(m_tableName, cols);

        // Add data to the table
        ps = helper.prepareInsert(m_tableName, cols);

        add(ps, "1234", "Karl Moss", "46.35");
        add(ps, "5323", "Simon Yates", "143.76");
        add(ps, "3982", "Alan Rose", "887.32");
        add(ps, "9371", "John Smith", "231.28");

      }
      catch (Exception ex) {
        ex.printStackTrace();
      }
      finally {

        // Make sure we always clean up after ourselves
        if (con != null) {
          try {
            ps.close();
            con.close();
          }
          catch (Exception ex) {
          }
        }
      }

    }

  /**
    * <p>Adds a record to the Customer database with the
    * given parameters
    *
    * @param ps Prepared statement
    * @param Custno Employee number
    * @param Name Employee name
    * @param Balance Current account balance
    * employee's picture
    */
  private void add(java.sql.PreparedStatement ps,
                   String Custno, String Name, String Balance)
    throws Exception
    {
      ps.setString(1, Custno);
      ps.setString(2, Name);
      ps.setString(3, Balance);
      ps.execute();
    }
  
  /**
    * <p>Trace the given string
    */
  private void trace(String s)
    {
      System.out.println("BuildCustomer: " + s);
    }
  
}
